@@ -25,84 +25,73 @@ class DescribeDcdnIpaUserDomainsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dcdn', '2018-01-15', 'DescribeDcdnIpaUserDomains')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_PageNumber(self):
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_CheckDomainShow(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_CheckDomainShow(self): # Boolean
 		return self.get_query_params().get('CheckDomainShow')
 
-	def set_CheckDomainShow(self,CheckDomainShow):
-		self.add_query_param('CheckDomainShow',CheckDomainShow)
-
-	def get_ResourceGroupId(self):
+	def set_CheckDomainShow(self, CheckDomainShow):  # Boolean
+		self.add_query_param('CheckDomainShow', CheckDomainShow)
+	def get_ResourceGroupId(self): # String
 		return self.get_query_params().get('ResourceGroupId')
 
-	def set_ResourceGroupId(self,ResourceGroupId):
-		self.add_query_param('ResourceGroupId',ResourceGroupId)
-
-	def get_SecurityToken(self):
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
+	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_PageSize(self):
+	def set_SecurityToken(self, SecurityToken):  # String
+		self.add_query_param('SecurityToken', SecurityToken)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_Tags(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_Tags(self): # RepeatList
 		return self.get_query_params().get('Tag')
 
-	def set_Tags(self, Tags):
-		for depth1 in range(len(Tags)):
-			if Tags[depth1].get('Value') is not None:
-				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tags[depth1].get('Value'))
-			if Tags[depth1].get('Key') is not None:
-				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tags[depth1].get('Key'))
-
-	def get_FuncFilter(self):
+	def set_Tags(self, Tag):  # RepeatList
+		for depth1 in range(len(Tag)):
+			if Tag[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
+			if Tag[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
+	def get_FuncFilter(self): # String
 		return self.get_query_params().get('FuncFilter')
 
-	def set_FuncFilter(self,FuncFilter):
-		self.add_query_param('FuncFilter',FuncFilter)
-
-	def get_DomainName(self):
+	def set_FuncFilter(self, FuncFilter):  # String
+		self.add_query_param('FuncFilter', FuncFilter)
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_OwnerId(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_FuncId(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_FuncId(self): # String
 		return self.get_query_params().get('FuncId')
 
-	def set_FuncId(self,FuncId):
-		self.add_query_param('FuncId',FuncId)
-
-	def get_DomainStatus(self):
+	def set_FuncId(self, FuncId):  # String
+		self.add_query_param('FuncId', FuncId)
+	def get_DomainStatus(self): # String
 		return self.get_query_params().get('DomainStatus')
 
-	def set_DomainStatus(self,DomainStatus):
-		self.add_query_param('DomainStatus',DomainStatus)
-
-	def get_DomainSearchType(self):
+	def set_DomainStatus(self, DomainStatus):  # String
+		self.add_query_param('DomainStatus', DomainStatus)
+	def get_DomainSearchType(self): # String
 		return self.get_query_params().get('DomainSearchType')
 
-	def set_DomainSearchType(self,DomainSearchType):
-		self.add_query_param('DomainSearchType',DomainSearchType)
\ No newline at end of file
+	def set_DomainSearchType(self, DomainSearchType):  # String
+		self.add_query_param('DomainSearchType', DomainSearchType)
